<?php
/**
 * @package      ITPrism Components
 * @subpackage   ItpMeta
 * @author       Todor Iliev
 * @copyright    Copyright (C) 2010 Todor Iliev <todor@itprism.com>. All rights reserved.
 * @license      http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * ItpMeta is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 */

// No direct access
defined('_JEXEC') or die();

jimport('joomla.application.component.controllerform');

/**
 * Url controller class.
 *
 * @package		ITPrism Components
 * @subpackage	ITPMeta
 * @since		1.6
 */
class ItpMetaControllerUrl extends JControllerForm {
    
    // Check the table in so it can be edited.... we are done with it anyway
    private $defaultLink = 'index.php?option=com_itpmeta';
    
    /**
     * Save an item
     *
     */
    public function save(){
        
        JRequest::checkToken() or jexit(JText::_('JINVALID_TOKEN'));
        
        $msg = "";
        
        // Gets the data from the form
        $data = JRequest::getVar('jform', array(), 'post', 'array');
        
        $model = $this->getModel("Url", "ItpMetaModel");
        
        // Validate the posted data.
        // Sometimes the form needs some posted data, such as for plugins and modules.
        $form = $model->getForm($data, false);
        /* @var $form JForm */
        
        try{
            
            if(!$form){
                throw new ItpException($model->getError(), 500);
            }
            
            // Test if the data is valid.
            $validData = $model->validate($form, $data);
            
            // Check for validation errors.
            if($validData === false){
                $itemId = JArrayHelper::getValue($validData, "id");
                // Get the validation messages.
                throw new ItpUserException($model->getError(), 500);
            }
            
            $model->save($data);
            $itemId = $model->getState("url.id");
            
            $msg = JText::_('COM_ITPMETA_URLS_SAVED');
        
        }catch(ItpUserException $e){
            
            $msg = "";
            JError::raiseWarning(500, $e->getMessage());
        
        }catch(Exception $e){
            
            $itpSecurity = new ItpSecurity($e);
            $itpSecurity->AlertMe();
            
            JError::raiseError(500, JText::_('ITP_ERROR_SYSTEM'));
            jexit(JText::_('ITP_ERROR_SYSTEM'));
        
        }
        
        $task = $this->getTask();
        
        switch($task) {
            case "apply":
                $this->defaultLink .= "&view=url&layout=edit";
                if(!empty($itemId)){
                    $this->defaultLink .= "&id=" . (int)$itemId;
                }
                break;
            case "save2new":    
                 $this->defaultLink .= "&view=url&layout=edit";
                break;
            default:
                $this->defaultLink .= "&view=urls";
                break;
        }
        
        $this->setRedirect(JRoute::_($this->defaultLink, false), $msg);
    
    }
    
    /**
     * Cancel operations
     *
     */
    public function cancel(){
        
        $msg = "";
        $this->setRedirect(JRoute::_($this->defaultLink . "&view=urls", false), $msg);
    
    }
    
}